﻿using System.Windows;

using DevExpress.Xpf.Editors;
using DevExpress.Xpf.Editors.Helpers;
using DevExpress.Xpf.Editors.Settings;

namespace TestProject
{
    /// <summary>
    /// 커스텀 텍스트 에디터 설정
    /// </summary>
    public class CustomTextEditSettings : TextEditSettings
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region Field

        /// <summary>
        /// 디폴트 에디터 여부 속성
        /// </summary>
        public static readonly DependencyProperty IsDefaultEditorProperty;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 디폴트 에디터 여부 - IsDefaultEditor

        /// <summary>
        /// 디폴트 에디터 여부
        /// </summary>
        public bool IsDefaultEditor
        {
            get
            {
                return (bool)GetValue(IsDefaultEditorProperty);
            }
            set
            {
                SetValue(IsDefaultEditorProperty, value);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Static

        #region 생성자 - CustomTextEditSettings()

        /// <summary>
        /// 생성자
        /// </summary>
        static CustomTextEditSettings()
        {
            IsDefaultEditorProperty = DependencyProperty.Register("IsDefaultEditor", typeof(bool), typeof(CustomTextEditSettings));

            RegisterCustomEdit();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 커스텀 에디터 등록하기 - RegisterCustomEdit()

        /// <summary>
        /// 커스텀 에디터 등록하기
        /// </summary>
        public static void RegisterCustomEdit()
        {
            EditorSettingsProvider.Default.RegisterUserEditor
            (
                typeof(CustomTextEdit),
                typeof(CustomTextEditSettings),
                () => new CustomTextEdit(),
                () => new CustomTextEditSettings()
            );
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Instance
        //////////////////////////////////////////////////////////////////////////////// Protected

        #region 에디터 코어 할당하기 - AssignToEditCore(pBaseEdit)

        /// <summary>
        /// 에디터 코어 할당하기
        /// </summary>
        /// <param name="pBaseEdit">IBaseEdit 객체</param>
        protected override void AssignToEditCore(IBaseEdit pBaseEdit)
        {
            base.AssignToEditCore(pBaseEdit);

            CustomTextEdit customTextEdit = pBaseEdit as CustomTextEdit;

            if(customTextEdit == null)
            {
                return;
            }

            SetValueFromSettings(IsDefaultEditorProperty, () => customTextEdit.IsDefaultEditor = IsDefaultEditor);
        }

        #endregion
    }
}